@@ -383,11 +383,7 @@ class Job(DAG):
             raise DagobahError('job cannot be started in its current state; ' +
                                'it is probably already running')
 
-        self.snapshot = deepcopy(self.graph)
-
-        is_valid, reason = self.validate(self.snapshot)
-        if not is_valid:
-            raise DagobahError(reason)
+        self.initialize_snapshot()
 
         # don't increment if the job was run manually
         if self.cron_iter and datetime.utcnow() > self.next_run:
@@ -414,6 +410,8 @@ class Job(DAG):
     def retry(self):
         """ Restarts failed tasks of a job. """
 
+        self.initialize_snapshot()
+
         failed_task_names = []
         for task_name, log in self.run_log['tasks'].items():
             if log.get('success', True) == False:
@@ -597,8 +595,7 @@ class Job(DAG):
             finally:
                 self.backend.release_lock()
 
-        self.snapshot = None
-
+        self.destroy_snapshot()
         self.completion_lock.release()
 
 
@@ -659,6 +656,24 @@ class Job(DAG):
             result = json.loads(json.dumps(result, cls=StrictJSONEncoder))
         return result
 
+    def initialize_snapshot(self):
+        """ Copy the DAG and validate """
+        if self.snapshot is not None:
+            raise DagobahError("Attempting to initialize DAG snapshot without "
+                               + "first destroying old snapshot.")
+
+        snapshot_to_validate = deepcopy(self.graph)
+
+        is_valid, reason = self.validate(snapshot_to_validate)
+        if not is_valid:
+            raise DagobahError(reason)
+
+        self.snapshot = snapshot_to_validate
+
+    def destroy_snapshot(self):
+        """ Destroy active copy of the snapshot """
+        self.snapshot = None
+
 
 class Task(object):
     """ Handles execution and reporting for an individual process.
